aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPFavoriteNode.h
diff options
context:
space:
mode:
authorstuconnolly <stuart02@gmail.com>2010-11-11 16:53:24 +0000
committerstuconnolly <stuart02@gmail.com>2010-11-11 16:53:24 +0000
commitb1bc59225d7f190b6db36da4634cc96095f01591 (patch)
tree95cfdcc96dfbb48750d9f0afa79569591d04bea0 /Source/SPFavoriteNode.h
parentb8fc79dd357d8dd1cf3177d1a7faef030497a9e0 (diff)
downloadsequelpro-b1bc59225d7f190b6db36da4634cc96095f01591.tar.gz
sequelpro-b1bc59225d7f190b6db36da4634cc96095f01591.tar.bz2
sequelpro-b1bc59225d7f190b6db36da4634cc96095f01591.zip
Refactor the favorite node class and fix auto-selection of the default or last used favorite.
Diffstat (limited to 'Source/SPFavoriteNode.h')
-rw-r--r--Source/SPFavoriteNode.h29
1 files changed, 19 insertions, 10 deletions
diff --git a/Source/SPFavoriteNode.h b/Source/SPFavoriteNode.h
index 0493ae70..d3b25854 100644
--- a/Source/SPFavoriteNode.h
+++ b/Source/SPFavoriteNode.h
@@ -29,28 +29,37 @@
* @author Stuart Connolly http://stuconnolly.com/
*
* This class is designed to be a simple wrapper around a connection favorite to allow us to easily represent
- * them in a tree structure for use in an outline view.
+ * them in a tree structure for use in an outline view. If the node is a group item (i.e. a folder) then it
+ * should have a name as well as zero or more child nodes. Similarly, actual connection favorite nodes, don't
+ * have a name and should have no children.
*/
@interface SPFavoriteNode : NSObject
{
- BOOL isGroup;
- NSDictionary *favorite;
- NSMutableArray *children;
+ BOOL nodeIsGroup;
+ NSString *nodeName;
+
+ NSDictionary *nodeFavorite;
+ NSMutableArray *nodeChildren;
}
/**
* @property isGroup Indicates whether this node is a group item
*/
-@property (readwrite, assign) BOOL isGroup;
+@property (readwrite, assign) BOOL nodeIsGroup;
/**
- * @property favorite The actual favorite dictionary
+ * @property nodeName The node's name if it's a group item
*/
-@property (readwrite, retain) NSDictionary *favorite;
+@property (readwrite, retain) NSString *nodeName;
/**
- * @property children This node's children
+ * @property nodeFavorite The actual favorite dictionary
*/
-@property (readwrite, retain) NSMutableArray *children;
+@property (readwrite, retain) NSDictionary *nodeFavorite;
+
+/**
+ * @property nodeChildren This node's children
+ */
+@property (readwrite, retain) NSMutableArray *nodeChildren;
@end
@@ -29,28 +29,37 @@
}
/**
- * @property isGroup Indicates whether this node is a group item
+ * @property nodeIsGroup Indicates whether this node is a group item
*/